@@ -16,10 +16,8 @@
 ;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ;; GNU General Public License for more details.
 ;;
-;; You should have received a copy of the GNU General Public
-;; License along with Guile-WWW; see the file COPYING.  If not,
-;; write to the Free Software Foundation, Inc., 51 Franklin Street,
-;; Fifth Floor, Boston, MA  02110-1301  USA
+;; You should have received a copy of the GNU General Public License
+;; along with Guile-WWW.  If not, see <http://www.gnu.org/licenses/>.
 
 ;;; Code:
 
@@ -46,6 +44,7 @@
   #:autoload (www post) (formatted-form-for-http:post-form)
   #:use-module ((srfi srfi-1) #:select (car+cdr))
   #:use-module ((srfi srfi-11) #:select (let-values))
+  #:use-module ((srfi srfi-13) #:select (string-titlecase))
   #:use-module ((www url) #:select (url:host
                                     url:port
                                     url:path))
